@@ -81,7 +81,7 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Na
   LOG_FORMAT                => " %s [%s] %s\n",
 };
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.1.1';
 
 use vars qw{ @EXPORT_OK };
 
@@ -1578,8 +1578,6 @@ credentials will be cached even if cacheing is turned off.
 
 =back
 
-=over 5
-
 =item Option 2 - Remove them manually after use
 
 Call the C<reset_credentials()> with a false value after
@@ -1610,12 +1608,12 @@ the credentials which is less than ideal. To avoid storing the passkey
 with the credentials, pass a reference to a subroutine that will
 provide the passkey for encryption and decryption. You can even use
 the same passkey generator that is used by C<Amazon::Credentials>
-(C<create_passkey).
+(C<create_passkey>).
 
 The point here is to avoid storing credentials in the same object as
 the credentials to minimize the likelihood of exposing your
 credentials or your methods for encryption in logs...better but
-perfect. It's still possible to expose your passkey and your
+not perfect. It's still possible to expose your passkey and your
 credentials if you are not careful.
 
  my $passkey = Amazon::Credentials::create_passkey;
@@ -1679,18 +1677,6 @@ module will not write log messages that contain your credentials even
 if your debug flag is set to a true value. In order to debug output of
 all content you the C<insecure> flag to any of the values shown below.
 
-=head2 Use Temporary Credentials
-
-One additional tip to help prevent the use of your credentials even if
-they have been exposed in logs or files. I<Use temporary credentials
-with short expiration times whenever possible.> C<Amazon::Credentials>
-provides methods to determine if your credentials have expired and
-a method to refresh them when they have.
-
- if ( $credentials->is_token_expired ) {
-   $credentials->refresh_token;
- }
-
 =over 5
 
 =item insecure = false (0, '', undef)
@@ -1710,6 +1696,20 @@ enable full debugging.
 
 =back
 
+=head2 Use Temporary Credentials
+
+One additional tip to help prevent the use of your credentials even if
+they have been exposed in logs or files. I<Use temporary credentials
+with short expiration times whenever possible.> C<Amazon::Credentials>
+provides methods to determine if your credentials have expired and
+a method to refresh them when they have.
+
+ if ( $credentials->is_token_expired ) {
+   $credentials->refresh_token;
+ }
+
+=head2 Additonal Notes on Logging
+
 Versions I<1.0.18> and I<1.0.19> allowed you to enable debugging by
 setting the environment variable DEBUG to any true value to enable
 basic debug output. Version I<1.0.18> would log information to STDERR
